AutoLoader Changelog
====================

1.0.3 - 2022-03-20
------------------

- **support**: update to `minchin.releaser` 0.8.2, and thus officially support
  Python 3.10.

1.0.2 - 2021-10-24
------------------

- **feature**: original implementation
- **support**: first release to PyPI under `minchin.pelican.plugins.autoloader`_

.. _minchin.pelican.plugins.autoloader: https://pypi.org/project/minchin.pelican.plugins.autoloader/
